@@ -13,7 +13,7 @@ from jx_base.expressions import NumberOp as NumberOp_
 from jx_bigquery.expressions import _utils
 from jx_bigquery.expressions._utils import BQLang, check
 from mo_dots import wrap
-from mo_sql import sql_coalesce
+from jx_bigquery.sql import sql_coalesce
 
 
 class NumberOp(NumberOp_):
