@@ -16,7 +16,7 @@ from jx_bigquery.expressions.length_op import LengthOp
 from jx_bigquery.expressions.literal import Literal
 from jx_bigquery.expressions.right_op import RightOp
 from mo_dots import wrap
-from mo_sql import SQL_FALSE, SQL_TRUE
+from jx_bigquery.sql import SQL_FALSE, SQL_TRUE
 
 
 class SuffixOp(SuffixOp_):
